pub struct TextureCache {
pub textures: Vec<Texture>,
pub views: Vec<TextureView>,
pub default_white_view: TextureView,
pub default_normal_view: TextureView,
pub sampler: Sampler,
/* private fields */
}Fields
textures: Vec<Texture>views: Vec<TextureView>default_white_view: TextureViewdefault_normal_view: TextureViewsampler: SamplerImplementations
Sourceimpl TextureCache
impl TextureCache
pub fn new(device: &Device, queue: &Queue) -> Self
Sourcepub fn upload_image(
&mut self,
device: &Device,
queue: &Queue,
image: &RgbaImage,
label: &str,
srgb: bool,
) -> usize
pub fn upload_image( &mut self, device: &Device, queue: &Queue, image: &RgbaImage, label: &str, srgb: bool, ) -> usize
Upload an image to the GPU, returns texture index
Sourcepub fn get_view(&self, index: Option<usize>) -> &TextureView
pub fn get_view(&self, index: Option<usize>) -> &TextureView
Get texture view by index, or default white texture if index is None
Sourcepub fn get_normal_view(&self, index: Option<usize>) -> &TextureView
pub fn get_normal_view(&self, index: Option<usize>) -> &TextureView
Get normal texture view by index, or default normal if None